.. OGitM documentation master file, created by
   sphinx-quickstart on Fri Mar 13 17:56:36 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to OGitM's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   installation
   tutorial
   search_queries
   apidocs/api_docs


Indices and tables
==================

* :ref:`genindex`
